@@ -12,7 +12,7 @@ from ...utils.global_vars import gSmall
 from ...utils.error import FinError
 
 from ...products.equity.equity_option import EquityOption
-from ...utils.global_types import FinOptionTypes
+from ...utils.global_types import OptionTypes
 from ...market.curves.discount_curve_flat import DiscountCurve
 from ...utils.helpers import label_to_string, check_argument_types
 from ...utils.date import Date
@@ -46,9 +46,9 @@ def _f(ss, *args):
     q = args[8]
 
     v_call = bs_value(ss, tc - t, kc, rtc, q, v,
-                      FinOptionTypes.EUROPEAN_CALL.value)
+                      OptionTypes.EUROPEAN_CALL.value)
     v_put = bs_value(ss, tp - t, kp, rtp, q, v,
-                     FinOptionTypes.EUROPEAN_PUT.value)
+                     OptionTypes.EUROPEAN_PUT.value)
 
     v = v_call - v_put
     return v
@@ -215,14 +215,14 @@ class EquityChooserOption(EquityOption):
         s_2 = s / m
 
         v_call_1 = bs_value(s_1, tc - t, kc, rtc, q, v,
-                            FinOptionTypes.EUROPEAN_CALL.value)
+                            OptionTypes.EUROPEAN_CALL.value)
         v_put_1 = bs_value(s_1, tp - t, kp, rtp, q, v,
-                           FinOptionTypes.EUROPEAN_PUT.value)
+                           OptionTypes.EUROPEAN_PUT.value)
 
         v_call_2 = bs_value(s_2, tc - t, kc, rtc, q, v,
-                            FinOptionTypes.EUROPEAN_CALL.value)
+                            OptionTypes.EUROPEAN_CALL.value)
         v_put_2 = bs_value(s_2, tp - t, kp, rtp, q, v,
-                           FinOptionTypes.EUROPEAN_PUT.value)
+                           OptionTypes.EUROPEAN_PUT.value)
 
         payoff_1 = np.maximum(v_call_1, v_put_1)
         payoff_2 = np.maximum(v_call_2, v_put_2)
