@@ -14,7 +14,7 @@ from ...models.gbm_process_simulator import FinGBMProcess
 from ...products.equity.equity_option import EquityOption
 from ...utils.helpers import label_to_string, check_argument_types
 from ...market.curves.discount_curve import DiscountCurve
-from ...utils.global_types import FinOptionTypes
+from ...utils.global_types import OptionTypes
 
 ##########################################################################
 # TODO: Attempt control variate adjustment to monte carlo
@@ -37,14 +37,14 @@ class EquityFixedLookbackOption(EquityOption):
 
     def __init__(self,
                  expiry_date: Date,
-                 option_type: FinOptionTypes,
+                 option_type: OptionTypes,
                  strike_price: float):
         """ Create the FixedLookbackOption by specifying the expiry date, the
         option type and the option strike. """
 
         check_argument_types(self.__init__, locals())
 
-        if option_type != FinOptionTypes.EUROPEAN_CALL and option_type != FinOptionTypes.EUROPEAN_PUT:
+        if option_type != OptionTypes.EUROPEAN_CALL and option_type != OptionTypes.EUROPEAN_PUT:
             raise FinError("Option type must be EUROPEAN_CALL or EUROPEAN_PUT")
 
         self._expiry_date = expiry_date
@@ -79,11 +79,11 @@ class EquityFixedLookbackOption(EquityOption):
         smin = 0.0
         smax = 0.0
 
-        if self._option_type == FinOptionTypes.EUROPEAN_CALL:
+        if self._option_type == OptionTypes.EUROPEAN_CALL:
             smax = stock_min_max
             if smax < s0:
                 raise FinError("The Smax value must be >= the stock price.")
-        elif self._option_type == FinOptionTypes.EUROPEAN_PUT:
+        elif self._option_type == OptionTypes.EUROPEAN_PUT:
             smin = stock_min_max
             if smin > s0:
                 raise FinError("The Smin value must be <= the stock price.")
@@ -102,7 +102,7 @@ class EquityFixedLookbackOption(EquityOption):
         sqrtT = np.sqrt(t)
 
         # Taken from Hull Page 536 (6th edition) and Haug Page 143
-        if self._option_type == FinOptionTypes.EUROPEAN_CALL:
+        if self._option_type == OptionTypes.EUROPEAN_CALL:
 
             if k > smax:
 
@@ -134,7 +134,7 @@ class EquityFixedLookbackOption(EquityOption):
                 v = df * (smax - k) + s0 * dq * N(e1) - \
                     smax * df * N(e2) + s0 * df * u * term
 
-        elif self._option_type == FinOptionTypes.EUROPEAN_PUT:
+        elif self._option_type == OptionTypes.EUROPEAN_PUT:
 
             if k >= smin:
                 f1 = (np.log(s0/smin) + (b + v * v / 2.0) * t) / v / sqrtT
@@ -201,12 +201,12 @@ class EquityFixedLookbackOption(EquityOption):
         smin = 0.0
         smax = 0.0
 
-        if self._option_type == FinOptionTypes.EUROPEAN_CALL:
+        if self._option_type == OptionTypes.EUROPEAN_CALL:
             smax = stock_min_max
             if smax < stock_price:
                 raise FinError(
                     "Smax must be greater than or equal to the stock price.")
-        elif self._option_type == FinOptionTypes.EUROPEAN_PUT:
+        elif self._option_type == OptionTypes.EUROPEAN_PUT:
             smin = stock_min_max
             if smin > stock_price:
                 raise FinError(
@@ -220,12 +220,12 @@ class EquityFixedLookbackOption(EquityOption):
         num_paths = 2 * num_paths
         payoff = np.zeros(num_paths)
 
-        if option_type == FinOptionTypes.EUROPEAN_CALL:
+        if option_type == OptionTypes.EUROPEAN_CALL:
             SMax = np.max(Sall, axis=1)
             smaxs = np.ones(num_paths) * smax
             payoff = np.maximum(SMax - k, 0.0)
             payoff = np.maximum(payoff, smaxs - k)
-        elif option_type == FinOptionTypes.EUROPEAN_PUT:
+        elif option_type == OptionTypes.EUROPEAN_PUT:
             SMin = np.min(Sall, axis=1)
             smins = np.ones(num_paths) * smin
             payoff = np.maximum(k - SMin, 0.0)
