@@ -11,7 +11,7 @@ from ...utils.date import Date
 from ...utils.math import ONE_MILLION
 from ...utils.global_vars import gDaysInYear
 from ...models.black_scholes import BlackScholes
-from ...utils.global_types import FinOptionTypes
+from ...utils.global_types import OptionTypes
 from .equity_vanilla_option import EquityVanillaOption
 from ...utils.helpers import label_to_string, check_argument_types
 
@@ -122,8 +122,8 @@ class EquityVarianceSwap:
         self._num_put_options = num_put_options
         self._num_call_options = num_call_options
 
-        call_type = FinOptionTypes.EUROPEAN_CALL
-        put_type = FinOptionTypes.EUROPEAN_PUT
+        call_type = OptionTypes.EUROPEAN_CALL
+        put_type = OptionTypes.EUROPEAN_PUT
 
         tmat = (self._maturity_date - valuation_date)/gDaysInYear
 
