@@ -164,27 +164,13 @@ class FXOneTouchOption(EquityOption):
     def value(self,
               valuation_date: Date,
               spot_fx_rate: (float, np.ndarray),
-              dom_discount_curve: DiscountCurve,
-              for_discount_curve: DiscountCurve,
+              domCurve: DiscountCurve,
+              forCurve: DiscountCurve,
               model):
         """ FX One-Touch Option valuation using the Black-Scholes model
         assuming a continuous (American) barrier from value date to expiry.
         Handles both cash-or-nothing and asset-or-nothing options."""
 
-        if isinstance(valuation_date, Date) == False:
-            raise FinError("Valuation date is not a Date")
-
-        if valuation_date > self._expiry_date:
-            raise FinError("Valuation date after expiry date.")
-
-        if dom_discount_curve._valuation_date != valuation_date:
-            raise FinError(
-                "Domestic Curve valuation date not same as option valuation date")
-
-        if for_discount_curve._valuation_date != valuation_date:
-            raise FinError(
-                "Foreign Curve valuation date not same as option valuation date")
-
         DEBUG_MODE = False
 
         print("USE WITH CAUTION. MORE TESTING REQUIRED.")
@@ -201,9 +187,9 @@ class FXOneTouchOption(EquityOption):
 
         sqrtT = np.sqrt(t)
 
-        df = dom_discount_curve.df(self._expiry_date)
-        rd = dom_discount_curve.cc_rate(self._expiry_date)
-        rf = for_discount_curve.cc_rate(self._expiry_date)
+        df = domCurve.df(self._expiry_date)
+        rd = domCurve.cc_rate(self._expiry_date)
+        rf = forCurve.cc_rate(self._expiry_date)
 
         v = model._volatility
         v = max(v, 1e-6)
@@ -229,8 +215,7 @@ class FXOneTouchOption(EquityOption):
             eta = 1.0
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
             A5_1 = np.power(H/s0, mu + lam) * n_vect(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta *
-                                                     z - 2.0 * eta * lam * v * sqrtT)
+            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -243,8 +228,7 @@ class FXOneTouchOption(EquityOption):
             eta = -1.0
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
             A5_1 = np.power(H/s0, mu + lam) * n_vect(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta *
-                                                     z - 2.0 * eta * lam * v * sqrtT)
+            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -258,8 +242,7 @@ class FXOneTouchOption(EquityOption):
             K = H
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
             A5_1 = np.power(H/s0, mu + lam) * n_vect(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta *
-                                                     z - 2.0 * eta * lam * v * sqrtT)
+            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -273,8 +256,7 @@ class FXOneTouchOption(EquityOption):
             K = H
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
             A5_1 = np.power(H/s0, mu + lam) * n_vect(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta *
-                                                     z - 2.0 * eta * lam * v * sqrtT)
+            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta * z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
@@ -289,8 +271,7 @@ class FXOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
-                n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 + B4)
             return v
 
@@ -306,8 +287,7 @@ class FXOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
-                n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 + B4)
             return v
 
@@ -355,8 +335,7 @@ class FXOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
-                n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 - B4)
             return v
 
@@ -372,8 +351,7 @@ class FXOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
-                n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 - B4)
             return v
 
@@ -419,14 +397,14 @@ class FXOneTouchOption(EquityOption):
 ###############################################################################
 
     def value_mc(self,
-                 valuation_date: Date,
-                 stock_price: float,
-                 domCurve: DiscountCurve,
-                 forCurve: DiscountCurve,
-                 model,
-                 num_paths: int = 10000,
-                 num_steps_per_year: int = 252,
-                 seed: int = 4242):
+                valuation_date: Date,
+                stock_price: float,
+                domCurve: DiscountCurve,
+                forCurve: DiscountCurve,
+                model,
+                num_paths: int = 10000,
+                num_steps_per_year: int = 252,
+                seed: int = 4242):
         """ Touch Option valuation using the Black-Scholes model and Monte
         Carlo simulation. Accuracy is not great when compared to the analytical
         result as we only observe the barrier a finite number of times. The
