@@ -34,7 +34,8 @@ class SwapFixedLeg:
                  payment_lag: int = 0,
                  calendar_type: CalendarTypes = CalendarTypes.WEEKEND,
                  bus_day_adjust_type: BusDayAdjustTypes = BusDayAdjustTypes.FOLLOWING,
-                 date_gen_rule_type: DateGenRuleTypes = DateGenRuleTypes.BACKWARD):
+                 date_gen_rule_type: DateGenRuleTypes = DateGenRuleTypes.BACKWARD, 
+                 end_of_month:bool = False):
         """ Create the fixed leg of a swap contract giving the contract start
         date, its maturity, fixed coupon, fixed leg frequency, fixed leg day
         count convention and notional.  """
@@ -67,6 +68,7 @@ class SwapFixedLeg:
         self._calendar_type = calendar_type
         self._bus_day_adjust_type = bus_day_adjust_type
         self._date_gen_rule_type = date_gen_rule_type
+        self._end_of_month = end_of_month
 
         self._startAccruedDates = []
         self._endAccruedDates = []
@@ -93,7 +95,8 @@ class SwapFixedLeg:
                             self._freq_type,
                             self._calendar_type,
                             self._bus_day_adjust_type,
-                            self._date_gen_rule_type)
+                            self._date_gen_rule_type, 
+                            end_of_month=self._end_of_month)
 
         scheduleDates = schedule._adjusted_dates
 
@@ -103,6 +106,7 @@ class SwapFixedLeg:
         self._startAccruedDates = []
         self._endAccruedDates = []
         self._payment_dates = []
+        self._payments = []
         self._year_fracs = []
         self._accrued_days = []
         self._rates = []
