@@ -2,23 +2,24 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-import numpy as np
-import matplotlib.pyplot as plt
-from financepy.utils.date import Date
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.products.rates.ibor_fra import IborFRA
-from financepy.products.rates.ibor_future import IborFuture
-from financepy.products.rates.ibor_deposit import IborDeposit
-from financepy.products.rates.ibor_swap import IborSwap
-from financepy.market.curves.interpolator import InterpTypes
-from financepy.utils.math import ONE_MILLION
-from financepy.utils.global_types import SwapTypes
-from financepy.products.rates.ibor_single_curve import IborSingleCurve
-from financepy.products.rates.dual_curve import IborDualCurve
-from financepy.products.rates.ois_curve import OISCurve
-from financepy.products.rates.ois import OIS
 from FinTestCases import FinTestCases, globalTestCaseMode
+from financepy.products.rates.ois import OIS
+from financepy.products.rates.ois_curve import OISCurve
+from financepy.products.rates.dual_curve import IborDualCurve
+from financepy.products.rates.ibor_single_curve import IborSingleCurve
+from financepy.utils.global_types import SwapTypes
+from financepy.utils.math import ONE_MILLION
+from financepy.market.curves.interpolator import InterpTypes
+from financepy.products.rates.ibor_swap import IborSwap
+from financepy.products.rates.ibor_deposit import IborDeposit
+from financepy.products.rates.ibor_future import IborFuture
+from financepy.products.rates.ibor_fra import IborFRA
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.date import Date
+import matplotlib.pyplot as plt
+import numpy as np
+
 import sys
 sys.path.append("..")
 
@@ -259,7 +260,7 @@ def test_bloombergPricingExample():
         valuation_date, libor_curve, libor_curve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         valuation_date, libor_curve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         valuation_date, libor_curve, libor_curve, None))
 
     testCases.banner("======================================================")
@@ -269,7 +270,7 @@ def test_bloombergPricingExample():
         settlement_date, libor_curve, libor_curve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         settlement_date, libor_curve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         settlement_date, libor_curve, libor_curve, None))
     testCases.banner("======================================================")
 
@@ -290,7 +291,7 @@ def test_bloombergPricingExample():
         valuation_date, oisCurve, liborDualCurve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         valuation_date, oisCurve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         valuation_date, oisCurve, libor_curve, None))
 
     testCases.header("VALUATION TO SWAP SETTLEMENT DATE", " PV")
@@ -298,7 +299,7 @@ def test_bloombergPricingExample():
         settlement_date, oisCurve, liborDualCurve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         settlement_date, oisCurve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         settlement_date, oisCurve, liborDualCurve, None, ))
 
 #    swaps[0].print_fixed_leg_pv()
