@@ -2,23 +2,24 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-import time as time
-import numpy as np
-import matplotlib.pyplot as plt
-from financepy.utils.date import Date
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.utils.calendar import CalendarTypes
-from financepy.products.rates.ibor_single_curve import IborSingleCurve
-from financepy.products.rates.ibor_fra import IborFRA
-from financepy.products.rates.ibor_future import IborFuture
-from financepy.products.rates.ibor_deposit import IborDeposit
-from financepy.products.rates.ibor_swap import IborSwap
-from financepy.utils.calendar import BusDayAdjustTypes
-from financepy.market.curves.interpolator import InterpTypes
-from financepy.utils.math import ONE_MILLION
-from financepy.utils.global_types import SwapTypes
 from FinTestCases import FinTestCases, globalTestCaseMode
+from financepy.utils.global_types import SwapTypes
+from financepy.utils.math import ONE_MILLION
+from financepy.market.curves.interpolator import InterpTypes
+from financepy.utils.calendar import BusDayAdjustTypes
+from financepy.products.rates.ibor_swap import IborSwap
+from financepy.products.rates.ibor_deposit import IborDeposit
+from financepy.products.rates.ibor_future import IborFuture
+from financepy.products.rates.ibor_fra import IborFRA
+from financepy.products.rates.ibor_single_curve import IborSingleCurve
+from financepy.utils.calendar import CalendarTypes
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.date import Date
+import matplotlib.pyplot as plt
+import numpy as np
+import time as time
+
 import sys
 sys.path.append("..")
 
@@ -318,7 +319,7 @@ def test_ibor_depositsFRAsSwaps():
 # https://github.com/vilen22/curve-building/blob/master/Bloomberg%20Curve%20Building%20Replication.xlsx
 ###############################################################################
 ###############################################################################
-# AGREEMENT IS VERY CLOSE - NOT SURE ABOUT SIZE OF LAST PAYMENT ON FIXED LEG!
+# AGREEEMENT IS VERY CLOSE - NOT SURE ABOUT SIZE OF LAST PAYMENT ON FIXED LEG!
 
 
 def futureToFRARate(price, convexity):
@@ -739,7 +740,7 @@ def test_bloombergPricingExample(interp_type):
         valuation_date, libor_curve, libor_curve, None))
     testCases.print(
         "FIXED:", -swaps[0]._fixed_leg.value(valuation_date, libor_curve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         valuation_date, libor_curve, libor_curve, None))
 
     # Pay fixed so make fixed leg value negative
@@ -748,7 +749,7 @@ def test_bloombergPricingExample(interp_type):
         settlement_date, libor_curve, libor_curve, None))
     testCases.print(
         "FIXED:", -swaps[0]._fixed_leg.value(settlement_date, libor_curve))
-    testCases.print("FLOAT:", swaps[0]._float_leg.value(
+    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
         settlement_date, libor_curve, libor_curve, None))
 
     # swaps[0].print_fixed_leg_pv()
